from setuptools import setup, find_packages


setup(
    name='bannybwain',
    version='0.0.1',
    license='MIT',
    author="Pwince Patyrbanny",
    author_email='petreleonardos@gmail.com',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    url='https://github.com/petreleon/Bannybwain',
    keywords='example project',
    install_requires=[
      ],

)